
## CATO-CLI - mutation.site.removeCloudInterconnectPhysicalConnection:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeCloudInterconnectPhysicalConnection) for documentation on this operation.

### Usage for mutation.site.removeCloudInterconnectPhysicalConnection:

`catocli mutation site removeCloudInterconnectPhysicalConnection -h`

`catocli mutation site removeCloudInterconnectPhysicalConnection <json>`

`catocli mutation site removeCloudInterconnectPhysicalConnection "$(cat < removeCloudInterconnectPhysicalConnection.json)"`

`catocli mutation site removeCloudInterconnectPhysicalConnection '{"removeCloudInterconnectPhysicalConnectionInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for mutation.site.removeCloudInterconnectPhysicalConnection ####
`accountId` [ID] - (required) N/A 
`removeCloudInterconnectPhysicalConnectionInput` [RemoveCloudInterconnectPhysicalConnectionInput] - (required) N/A 
